@@ -240,7 +240,12 @@ class Components:
             df['annualized_std'] = "{:.0%}".format(df['annualized_std'] / 100)
 
             df['cov'] = round(df['cov'], 2)
-            df['win_rate'] = "{:.0%}".format(df['win_rate'] / 100)
+
+            try:
+                df['win_rate'] = "{:.0%}".format( float(df['win_rate']) / 100)
+            except Exception as e:
+                df['win_rate'] = '--'
+
             df['return_to_bah'] = "{:.0%}".format(df['return_to_bah'] / 100)
 
             df['bah_mdd_dollar'] = "{:,}".format(int(round(df['bah_mdd_dollar'], 0)))
@@ -248,11 +253,13 @@ class Components:
             df['bah_return'] = "{:.0%}".format(df['bah_return'] / 100)
             df['bah_annualized_return'] = "{:.0%}".format(df['bah_annualized_return'] / 100)
             df['bah_annualized_std'] = "{:.0%}".format(df['bah_annualized_std'] / 100)
-            # df['bah_annualized_sr'] = round(df['bah_annualized_sr'], 1)
+
         except Exception as e:
             # print(e)
             pass
 
+
+
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
         per_col_1_1.append(html.Div('Net Profit/MDD Ratio'))
@@ -1117,7 +1124,10 @@ class Components:
         num_of_trade = "{:,}".format(int(total_dict['num_of_trade']))
         net_profit = "{:,}".format(int(round(total_dict['net_profit'],0)) )
         net_profit_to_mdd = round(total_dict['net_profit_to_mdd'],2)
-        win_rate = "{:.0%}".format(total_dict['win_rate'])
+        try:
+            win_rate = "{:.0%}".format( float(total_dict['win_rate']) )
+        except:
+            win_rate = '--'
 
         total_commission = "{:,}".format(int(total_dict['total_commission']))
         return_on_capital = "{:.0%}".format(total_dict['return_on_capital'])
