@@ -594,7 +594,10 @@ class Plot:
                     self.mdd_dollar = df['mdd_dollar']
                     self.mdd_pct = df['mdd_pct']
                     self.num_of_trade = df['num_of_trade']
-                    self.num_of_win = round(int(df['num_of_trade'])*float(df['win_rate'])/100)
+                    try:
+                        self.num_of_win = round(int(df['num_of_trade'])*float(df['win_rate'])/100)
+                    except:
+                        self.num_of_win = '--'
                     self.return_on_capital = df['return_on_capital']
                     self.sharp = df['annualized_sr']
                     self.total_commission = df['total_commission']
